"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLaika = void 0;
const react_1 = require("react");
const config_1 = require("./config");
const utils_1 = require("./utils");
function useLaika(feature, uri, env, cacheTimeout) {
    var _a;
    const [enabled, setEnabled] = (0, react_1.useState)(false);
    const [isLoading, setIsLoading] = (0, react_1.useState)(true);
    const config = (0, react_1.useContext)(config_1.LaikaContext);
    const _uri = uri !== null && uri !== void 0 ? uri : config.uri;
    const _env = env !== null && env !== void 0 ? env : config.env;
    const _to = (_a = cacheTimeout !== null && cacheTimeout !== void 0 ? cacheTimeout : config.timeout) !== null && _a !== void 0 ? _a : utils_1.DEFAULT_TIMEOUT;
    if (_uri === undefined || _env === undefined || _to === undefined) {
        throw new Error(`Laika App not initialized (uri: ${_uri}, env: ${_env}, timeout: ${_to})`);
    }
    const isMounted = (0, react_1.useRef)(false);
    (0, utils_1.getFeatureStatus)(feature, _uri, _env, _to).then((isEnabled) => {
        if (isMounted.current) {
            setIsLoading(false);
            setEnabled(isEnabled);
        }
    });
    (0, react_1.useEffect)(() => {
        isMounted.current = true;
        return () => {
            isMounted.current = false;
        };
    }, []);
    return [enabled, isLoading];
}
exports.useLaika = useLaika;
