"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeatureStatus = exports.DEFAULT_TIMEOUT = void 0;
exports.DEFAULT_TIMEOUT = 1.5 * 60 * 1000;
function timeoutKey(key) {
    return `${key}_timeout`;
}
function store(key, value) {
    localStorage.setItem(key, JSON.stringify(value));
    localStorage.setItem(timeoutKey(key), String(Date.now()));
    return value;
}
function retrieve(key, retrievalFunction, timeout = exports.DEFAULT_TIMEOUT) {
    return __awaiter(this, void 0, void 0, function* () {
        const ts = localStorage.getItem(timeoutKey(key));
        const data = localStorage.getItem(key);
        if (ts === null || Date.now() - +ts > timeout || data === null) {
            const value = yield retrievalFunction();
            store(key, value);
            return value;
        }
        return JSON.parse(data);
    });
}
function parseLaikaResponse(res) {
    return __awaiter(this, void 0, void 0, function* () {
        const contentType = res.headers.get('content-type');
        if (contentType === null || !contentType.startsWith('application/json')) {
            throw new Error(`expected content-type to be application/json, got: ${contentType}`);
        }
        return res.json();
    });
}
function getLaikaFeatureStatus(feature, uri, env) {
    return __awaiter(this, void 0, void 0, function* () {
        const laikaUrl = `${uri}/api/features/${feature}/status/${env}`;
        const res = yield fetch(laikaUrl, {
            method: 'GET',
        });
        if (res.status !== 200) {
            throw new Error(`expected status code 200, got ${res.status}`);
        }
        if (!res.ok) {
            throw new Error('response is not ok');
        }
        const body = yield parseLaikaResponse(res);
        if (body === undefined) {
            throw new Error('Response Body is missing');
        }
        return Boolean(body);
    });
}
function getFeatureStatus(feature, uri, env, timeout = exports.DEFAULT_TIMEOUT) {
    return __awaiter(this, void 0, void 0, function* () {
        return retrieve(feature, () => getLaikaFeatureStatus(feature, uri, env), timeout);
    });
}
exports.getFeatureStatus = getFeatureStatus;
